/* Code to replicate Skills in the Marketplace: Testing Individual Bargaining Ability in a Field Based Experiment. Journal of Economic Behavior and Organization, 2015, 120: 174–188. */


clear

set memory 500m
set more off
ssc install outreg2
use "rents.dta" 

drop if individ==. | game_id==. | age==.

tab game_playerid, gen (ids)

gen game_total_rent000 = game_total_rent/1000
gen game_rent_buyer = game_total_rent000 * game_buyer

gen game_rent000= game_rent/1000

gen session_round= (game_session*10) + game_round
tab session_round, gen (session_rounds)

tab groupid, gen (groups)

sort game_id game_round
by game_id : gen game_rent_l=game_rent[_n-1]

gen game_round_efficiency =  game_round_rent/9600

// BASELINE CONTROLS
	
	gl D "age female"
	gl H "education literate voc_training adl numeracy_numcorrect_m"
	gl K "wealthindex savings_6mo_p99 cash4w_p99"
	gl S "prosocial groups_in"
	gl I "jumpy q157 q162 quarrelsome unloved q166 dishonest takethings disobeyparents curse threaten disputes"
	gl W "violence_by violence_against violence_others violence_witnessed"
	gl R "mosquitonet_resc wakalonenight_resc q123_resc q126_resc q127_resc q129_resc q131_resc q132_resc"
	gl P_e "pptemptresist_time_e ppmedwait_time_e pptakewarnings_time_e ppstopdoing_time_e pppostponeact_time_e ppspendmoney_time_e ppactquickly_time_e ppregretpast_time_e pptaskfirst_time_e ppchoosemed_time_e pptimepref1_e pptimepref2_e pptimepref3_e pptimepref4_e pptimepref5_e pptimepref6_e ppmakespend_e ppmakekeep_e pppatient_e ppatientcomp_e"
	gl P_m "pptemptresist_time_e_m ppmedwait_time_e_m pptakewarnings_time_e_m ppstopdoing_time_e_m pppostponeact_time_e_m ppspendmoney_time_e_m ppactquickly_time_e_m ppregretpast_time_e_m pptaskfirst_time_e_m ppchoosemed_time_e_m"
	gl P_m2 "pptemptresist_time_e_m ppmedwait_time_e_m pptakewarnings_time_e_m ppstopdoing_time_e_m pppostponeact_time_e_m ppspendmoney_time_e_m ppactquickly_time_e_m ppregretpast_time_e_m pptaskfirst_time_e_m ppchoosemed_time_e_m pptimepref1_e_m pptimepref2_e_m pptimepref3_e_m pptimepref4_e_m pptimepref5_e_m pptimepref6_e_m ppmakespend_e_m ppmakekeep_e_m pppatient_e_m ppatientcomp_e_m"
		 

// SOCIAL GLOBALS
		
	gl personality_e2 "grit conscientious industriousness"
	gl social_int "hhcaring_resc fam_disp_resc live_together helpelders_resc"
	gl support_e1 "lookedafterfam_resc distressed_resc mindoff_resc futureplans_resc helpfuladvice_resc listener_resc taughtsomething_resc jokedwith_resc"
	gl aggression "agg_quarrelsome agg_take agg_curse agg_threaten neigh_disp commlead_disp pol_disp fight_disp"
	gl aggression_e2 "quarrelsome_resc takethings_resc curse_resc threaten_resc wbyelled_resc wbreactedanger_resc wbfrustrateang_resc wbdamagemad_resc wbnowantang_resc wbangrythreat_resc wbhittinggood_resc wbhitdefend_resc wbdamagefun_resc wbforcewant_resc wbforcemoney_resc wbgangothers_resc wbweaponfight_resc wbyelledtodo_resc neigh_disp commlead_disp pol_disp fight_disp"
	gl community_e1 "comm_meet comm_mblzr comm_leader"
	gl community_e2 "cclcommeet12m_resc comm_mblzr ldmcomlc1 ldmcomother ldmacceptc1 rcaraiseissue12m_dum"
	gl contrpubgood_e2 "cpgroad12m_dum cpgwater12m_dum cpgbldgoth12m_dum cpgschl12m_dum cpglatrine12m_dum cpgoth12m_dum cpgfuneral12m_dum"
	gl protest_e2 "protests attptreasonjustified_resc attptviolencejustified_resc attptpolvioljustified_resc hcaptwish hcaptwouldgo hcaptwouldgoviol"
	gl election_action_e2 "epavoteredu2011el_dum epadiscussvote2011el_dum epareportinc2011el_dum regsuccess2011 vote2011elprez vote2011ellcv"
	gl partisan_e2 "pparally2011el_resc ppaprimary2011el_resc partyworked_resc partymember_resc "
	gl distress_ "jumpy_ unloved_ worried_ restless_ thinkpast_ nightmares_ lifediff_"
	

			foreach var of varlist jumpy q157 q162 quarrelsome unloved q166 dishonest takethings disobeyparents curse threaten disputes {
					qui sum `var' 
					qui gen Norm_`var'= (`var'-r(mean))/r(sd)
				}

				egen S_I=rowmean(Norm_*)
				sum S_I
				replace S_I = (S_I-r(mean))/r(sd)
				sum Norm_* S_I
				drop Norm_*

sum S_H
replace S_H = (S_H-r(mean))/r(sd)

sum S_K
replace S_K = (S_K-r(mean))/r(sd)

sum S_R
replace S_R = (S_R-r(mean))/r(sd)				

sum S_P_m
replace S_P_m = (S_P_m-r(mean))/r(sd)				

sum prosocial
replace prosocial = (prosocial-r(mean))/r(sd)				

sum aggression_n
replace aggression_n = (aggression_n-r(mean))/r(sd)				
				
				
/* Summary statistics */
/* Table 3 */
sum game_total_rent000 $D S_H S_K S_R S_P_m prosocial S_I aggression_n
				
				
/* Test of balance between buyers and sellers */
/* Table 4 */
foreach var of varlist $D S_H S_K S_R S_P_m prosocial S_I aggression_n {
	reg `var' game_buyer session_rounds*, cluster(game_id)
	outreg2 using balance, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append
	}


/* Test of who trades */
/* Table 5 */

reg  game_trade game_badtrade $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds* , cluster( game_id)
	outreg2 using trade, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(session_rounds*)  

reg  game_trade game_badtrade $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds* if  game_buyer==1, cluster(game_id)
	outreg2 using trade, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(session_rounds*)  append

reg  game_trade game_badtrade $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*  if  game_buyer==0, cluster(game_id)
	outreg2 using trade, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append
	

	
/* Correlate individual characteristics with game outcomes */
/* Table 6 */
reg game_rent game_badtrade game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*   if game_rent>0 , cluster( game_id)
	outreg2 using rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  

heckman game_rent game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*    if game_rent>0 , select(game_badtrade ) vce(cluster game_id)
	outreg2 using rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append
	
heckman game_rent $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*    if game_rent>0 & game_buyer==1, select(game_badtrade ) vce(cluster game_id)
	outreg2 using rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append

heckman game_rent $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*    if game_rent>0 & game_buyer==0, select(game_badtrade ) vce(cluster game_id)
	outreg2 using rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append


/* Test for what makes a market efficient */

foreach var of varlist $D S_H S_K S_R S_P_m prosocial S_I aggression_n {
	bysort game_session game_round: egen mean_`var' = mean(`var')
	}

foreach var of varlist $D S_H S_K S_R S_P_m prosocial S_I aggression_n {
	bysort game_session game_round: egen sd_`var' = sd(`var')
	gen var_`var'=(sd_`var')^2
	}

	
reg game_round_efficiency mean_*  if game_round==10, cluster(game_session)

reg game_round_efficiency mean_*  if game_round_efficiency <1 & game_round==10, cluster(game_session)

reg game_round_efficiency mean_*  if game_round_efficiency <1 & game_round_efficiency>.6822917 & game_round==10, cluster(game_session)

reg game_round_efficiency mean_*  if game_round_efficiency>.6822917 & game_round==10, cluster(game_session)
	
	
/* Correlate game with session characteristics */	
/* Table 7 */
**************problem coming from here***********
collapse (mean) game_round_efficiency game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n mean_* sd_* var_* session_round, by( game_session game_round)

reg game_round_efficiency mean_* session_round
	outreg2 using round_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append

reg game_round_efficiency mean_* session_round if game_round_efficiency <1
	outreg2 using round_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append

reg game_round_efficiency mean_* session_round if game_round_efficiency <1 & game_round_efficiency>.6822917
	outreg2 using round_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append

reg game_round_efficiency mean_* session_round if game_round_efficiency>.6822917
	outreg2 using round_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append


reg game_round_efficiency var* game_round, cluster(game_session)
	outreg2 using round_rents_var, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') 
	
reg game_round_efficiency var* game_round if game_round_efficiency <1, cluster(game_session)
	outreg2 using round_rents_var, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append

reg game_round_efficiency var* game_round if game_round_efficiency <1 & game_round_efficiency>.6822917, cluster(game_session)
	outreg2 using round_rents_var, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append

reg game_round_efficiency var* game_round if game_round_efficiency>.6822917, cluster(game_session)
	outreg2 using round_rents_var, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') append

/* Figure 3 */
hist game_round_efficiency


/* Correlate game with long-term economic outcomes */
/* Table 8 */
/*we should rerun the code from beginning to the end of table 6 and skip table 7*/
/*then start running table 8.*/
collapse (mean) wealthindex_e game_rent000 game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n game_session treated assigned  skilled_work4w_e revenues4w_real_p99_e bizasset_val_real_p99_e profits4w_real_p99_e consaggpercap2_real_e urban bizlog bizregister biztaxes employees employs return_school savings_real_p99, by( game_id)

tab game_session, gen (sessions)


* Intermediate outcomes
reg skilled_work4w_e game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  
	
reg bizlog game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append

reg bizregister  game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append

reg  biztaxes  game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append

reg bizasset_val_real_p99_e game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append
	
reg revenues4w_real_p99_e game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append
	
reg profits4w_real_p99_e game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append

reg consaggpercap2_real_e game_rent000 game_buyer sessions*
	outreg2 using YOP_intermediate, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*) append
	

* Wealth
reg wealthindex_e game_rent000 game_buyer sessions*
	outreg2 using YOP_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  

reg wealthindex_e game_rent000 game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n sessions*
	outreg2 using YOP_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  append

reg wealthindex_e game_rent000 game_buyer sessions* if game_buyer==1
	outreg2 using YOP_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  append

reg wealthindex_e game_rent000 game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n sessions* if game_buyer==1
	outreg2 using YOP_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  append

reg wealthindex_e game_rent000 game_buyer sessions* if game_buyer==0
	outreg2 using YOP_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  append

reg wealthindex_e game_rent000 game_buyer $D S_H S_K S_R S_P_m prosocial S_I aggression_n sessions* if game_buyer==0
	outreg2 using YOP_rents, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(sessions*)  append

	
/* Appendix analysis */ 
/*we should rerun the code from beginning to the end of table 6 and skip table 7 and 8*/
/*then start running appendix.*/
*problem*	
heckman game_rent game_rent_l $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*    if game_rent>0 & game_buyer==1, select(game_badtrade ) vce(cluster game_id)
	outreg2 using appendix, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  
	
heckman game_rent game_rent_l $D S_H S_K S_R S_P_m prosocial S_I aggression_n  session_rounds*    if game_rent>0 & game_buyer==0, select(game_badtrade ) vce(cluster game_id)
	outreg2 using appendix, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append

heckman game_rent $D $H $K $R $P_m prosocial $I $aggression  session_rounds* if game_rent>0 & game_buyer==1, select(game_badtrade ) vce(cluster game_id)
	outreg2 using appendix, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append
	
heckman game_rent $D $H $K $R $P_m prosocial $I $aggression  session_rounds* if game_rent>0 & game_buyer==0, select(game_badtrade ) vce(cluster game_id)
	outreg2 using appendix, excel alpha(0.01, 0.05, 0.10) symbol(***, **, *) bdec(3) br label ctitle(`lab') drop(  session_rounds*)  append

	

	